@@ -25,11 +25,14 @@ class Clock():
         self.drawing_area = drawing_area
 
         self.alarm_enabled = False
+        self.alarm_indicator_enabled = True
         self.alarm_time = None
 
         self.fill = False
         self.show_seconds = True
 
+        self.font_name = "Sans"
+
         self.color_r = 1.0
         self.color_g = 1.0
         self.color_b = 1.0
@@ -40,6 +43,7 @@ class Clock():
         self.time = datetime.today()
         self.context = self.drawing_area.window.cairo_create()
 
+        self.context.select_font_face(self.font_name, cairo.FONT_SLANT_NORMAL, cairo.FONT_WEIGHT_NORMAL)
         self.context.set_source_rgba(1.0, 1.0, 1.0, 0.0)
         self.context.set_operator(cairo.OPERATOR_SOURCE)
         self.context.paint()
@@ -49,7 +53,7 @@ class Clock():
         self.draw_clock()
         self.context.restore()
 
-        if self.alarm_enabled:
+        if self.alarm_enabled and self.alarm_indicator_enabled :
             self.draw_alarm_indicator()
 
     def draw_alarm_indicator(self):
@@ -63,15 +67,21 @@ class Clock():
     def get_alarm_enabled(self):
         return self.alarm_enabled
 
+    def get_alarm_indicator_enabled(self):
+        return self.alarm_indicator_enabled
+
     def get_alarm_time(self):
         return self.alarm_time
 
-    def get_gdk_color(self):
-        return gtk.gdk.Color(int(self.color_r * 65535), int(self.color_g * 65535), int(self.color_b * 65535))
-
     def get_fill(self):
         return self.fill
 
+    def get_font_name(self):
+        return self.font_name
+
+    def get_gdk_color(self):
+        return gtk.gdk.Color(int(self.color_r * 65535), int(self.color_g * 65535), int(self.color_b * 65535))
+
     def get_show_seconds(self):
         return self.show_seconds
 
@@ -87,18 +97,21 @@ class Clock():
 
     def set_alarm_enabled(self, b):
         self.alarm_enabled = b
-        if self.alarm_enabled :
+        if self.alarm_enabled and self.alarm_indicator_enabled :
             self.resize_alarm_enabled()
         else :
             self.resize()
 
+    def set_alarm_indicator_enabled(self, b):
+        self.alarm_indicator_enabled = b
+
     def set_alarm_time(self, time):
         self.alarm_time = time
 
     def set_gdk_color(self, color):
-        self.color_r = int(color.red / 65535)
-        self.color_g = int(color.green / 65535)
-        self.color_b = int(color.blue / 65535)
+        self.color_r = color.red / 65535.0
+        self.color_g = color.green / 65535.0
+        self.color_b = color.blue / 65535.0
         
     def set_color(self, r, g, b):
         self.color_r = r
@@ -108,6 +121,9 @@ class Clock():
     def set_fill(self, b):
         self.fill = b
 
+    def set_font_name(self, f):
+        self.font_name = f
+
     def set_show_seconds(self, b):
         self.show_seconds = b
 
