@@ -19,6 +19,7 @@ import cairo
 from datetime import datetime
 import gtk
 import math
+import pango
 
 import clock
 
@@ -75,9 +76,9 @@ class DateTimeClock(clock.Clock):
             self.context.set_font_size(10)
 
             if self.show_seconds :
-                self.context.move_to(89, 35)
+                self.context.move_to(self.char_width * 9, 35)
             else :
-                self.context.move_to(65, 35)
+                self.context.move_to(self.char_width * 6, 35)
             
             self.context.text_path(abrv)
 
@@ -87,14 +88,19 @@ class DateTimeClock(clock.Clock):
                 self.context.stroke()
 
     def resize(self):
+        ctx = self.drawing_area.create_pango_context()
+        fdesc = pango.FontDescription(self.font_name + " 20")  
+        metric = ctx.get_metrics(fdesc)
+        self.char_width = int(metric.get_approximate_digit_width() / pango.SCALE * 0.7)
+
         if self.twelve_hour_mode :
             if self.show_seconds :
-                self.drawing_area.set_size_request(110, 36)
+                self.drawing_area.set_size_request(self.char_width * 11, 36)
             else:
-                self.drawing_area.set_size_request(80, 36)
+                self.drawing_area.set_size_request(self.char_width * 9, 36)
         else :
             if self.show_seconds :
-                self.drawing_area.set_size_request(90, 36)
+                self.drawing_area.set_size_request(self.char_width * 9, 36)
             else:
-                self.drawing_area.set_size_request(60, 36)
+                self.drawing_area.set_size_request(self.char_width * 6, 36)
 
