@@ -24,6 +24,8 @@ import gobject
 import hildon
 import hildondesktop
 import math
+import pango
+import pangocairo
 import os
 import re
 import sys
@@ -100,47 +102,71 @@ class AdvancedClockPlugin(hildondesktop.StatusMenuItem):
     def settings_cb(self, widget, data=None):
         dialog = hildon.Dialog()
         dialog.set_title("Advanced Clock Plugin Settings")
+        pa = hildon.PannableArea()
+        vb = gtk.VBox()
 
-        self.selector = hildon.TouchSelector(text = True)
+        selector = hildon.TouchSelector(text = True)
         for c in clocks :
-            self.selector.append_text(c.get_name())
+            selector.append_text(c.get_name())
 
         self.style_button = hildon.PickerButton(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
         self.style_button.set_title("Clock Style")
-        self.style_button.set_selector(self.selector)
+        self.style_button.set_selector(selector)
         self.style_button.set_active(self.clock_style)
-        dialog.vbox.pack_start(self.style_button, True, True, 0)
+        vb.pack_start(self.style_button, True, True, 0)
         self.style_button.show()
 
         self.show_seconds_button = hildon.CheckButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
         self.show_seconds_button.set_active(self.clock.get_show_seconds())
         self.show_seconds_button.set_label("Show seconds")
-        dialog.vbox.pack_start(self.show_seconds_button, True, True, 0)
+        vb.pack_start(self.show_seconds_button, True, True, 0)
         self.show_seconds_button.show()
 
         self.twelve_hour_mode_button = hildon.CheckButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
         self.twelve_hour_mode_button.set_active(self.clock.get_twelve_hour_mode())
         self.twelve_hour_mode_button.set_label("Twelve Hour Mode")
-        dialog.vbox.pack_start(self.twelve_hour_mode_button, True, True, 0)
+        vb.pack_start(self.twelve_hour_mode_button, True, True, 0)
         self.twelve_hour_mode_button.show()
 
         self.fill_button = hildon.CheckButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
         self.fill_button.set_active(self.clock.get_fill())
         self.fill_button.set_label("Fill")
-        dialog.vbox.pack_start(self.fill_button, True, True, 0)
+        vb.pack_start(self.fill_button, True, True, 0)
         self.fill_button.show()
 
+        self.alarm_indicator_button = hildon.CheckButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
+        self.alarm_indicator_button.set_active(self.clock.get_alarm_indicator_enabled())
+        self.alarm_indicator_button.set_label("Show Alarm Indicator")
+        vb.pack_start(self.alarm_indicator_button, True, True, 0)
+        self.alarm_indicator_button.show()
+
         self.color_button = gtk.ColorButton()
         self.color_button.set_color(self.clock.get_gdk_color())
         self.color_button.set_label("Color")
-        dialog.vbox.pack_start(self.color_button, True, True, 0)
+        vb.pack_start(self.color_button, True, True, 0)
         self.color_button.show()
 
+        fonts = pangocairo.cairo_font_map_get_default().list_families()
+        self.font_names = map(pango.FontFamily.get_name, fonts)
+        selector = hildon.TouchSelector(text = True)
+        for f in self.font_names :
+            selector.append_text(f)
+
+        self.font_button = hildon.PickerButton(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+        self.font_button.set_title("Font")
+        self.font_button.set_selector(selector)
+        self.font_button.set_active(self.font_names.index(self.clock.get_font_name()))
+        vb.pack_start(self.font_button, True, True, 0)
+        self.font_button.show() 
+
         ok_button = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Ok")
         ok_button.connect("clicked", self.settings_ok_cb, dialog)
         dialog.action_area.pack_start(ok_button, True, True, 0)
         ok_button.show()
 
+        pa.add_with_viewport(vb)
+        pa.set_size_request_policy("children")
+        dialog.vbox.pack_start(pa, True, True, 0)
         dialog.show_all()
 
     def settings_ok_cb(self, widget, dialog):
@@ -149,9 +175,11 @@ class AdvancedClockPlugin(hildondesktop.StatusMenuItem):
         old_clock = self.clock
         self.clock = getattr(clocks[self.clock_style], clock_names[self.clock_style])(self.drawing_area)
 
+        self.clock.set_alarm_indicator_enabled(self.alarm_indicator_button.get_active())
         self.clock.set_show_seconds(self.show_seconds_button.get_active())
         self.clock.set_twelve_hour_mode(self.twelve_hour_mode_button.get_active())
         self.clock.set_fill(self.fill_button.get_active())
+        self.clock.set_font_name(self.font_names[self.font_button.get_active()])
         self.clock.set_gdk_color(self.color_button.get_color())
 
         self.clock.resize()
